@@ -275,7 +275,7 @@ def _int_to_json(value):
 
 def _float_to_json(value):
     """Coerce 'value' to an JSON-compatible representation."""
-    return value
+    return value if value is None else float(value)
 
 
 def _decimal_to_json(value):
@@ -363,6 +363,11 @@ _SCALAR_VALUE_TO_JSON_ROW = {
     "DATETIME": _datetime_to_json,
     "DATE": _date_to_json,
     "TIME": _time_to_json,
+    # Make sure DECIMAL and BIGDECIMAL are handled, even though
+    # requests for them should be converted to NUMERIC.  Better safe
+    # than sorry.
+    "DECIMAL": _decimal_to_json,
+    "BIGDECIMAL": _decimal_to_json,
 }
 
 
